import { Component, OnInit } from "@angular/core";
import { ActivatedRoute } from "@angular/router";
import { MainService } from "../../../services/main.service";
import { ToolService } from 'src/app/services/tool.service';
import { NzMessageService } from 'ng-zorro-antd';

@Component({
  selector: "app-configuration-hospital",
  templateUrl: "./configuration-hospital.component.html",
  styleUrls: ["./configuration-hospital.component.less"],
})
export class ConfigurationHospitalComponent implements OnInit {
  constructor(
    private route: ActivatedRoute,
    private mainService: MainService,
    private tool: ToolService,
    private message: NzMessageService,
  ) {}

  coopData: any = {}; //当前操作列
  currentHospital; //当前院区

  ngOnInit() {
    this.currentHospital = this.tool.getCurrentHospital();
    this.getList();
  }

  // 新增/编辑表单提交
  btnLoading: boolean = false; //提交按钮loading状态
  submitMessageForm(): void {
    this.btnLoading = true;
    this.mainService
      .simplePost("addListData", "hospitalConfig", this.hospitalList)
      .subscribe((result) => {
        this.btnLoading = false;
        let msg = "保存";
        if (result.status == 200) {
          this.showPromptModal(msg, true, '');
        } else {
          this.showPromptModal(msg, false, result.msg);
        }
      });
  }

  // 获取列表
  loading1:boolean = false;
  hospitalList:any[] = [];
  getList() {
    let data = {
      idx: 0,
      sum: 9999,
      hospitalConfig: {
        hosId: this.currentHospital.id,
        model: 'itsm',
      },
    };
    this.loading1 = true;
    this.mainService
      .getFetchDataList("simple/data", "hospitalConfig", data)
      .subscribe((data) => {
        this.loading1 = false;
        if (data.status == 200) {
          this.hospitalList = data.list || [];
        }else{
          this.message.error(data.msg || "请求数据失败");
        }
      });
  }

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //操作提示框是否展示
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
    this.getList();
  }
}
