import { Component, OnInit, Input, Output, EventEmitter, ViewChild, ViewEncapsulation } from '@angular/core';
import { MainService } from '../../../services/main.service';
import { Router } from '@angular/router';
import { NzMessageService } from 'ng-zorro-antd';
import { FormGroup, Validators, FormBuilder } from '@angular/forms';
import { ToolService } from 'src/app/services/tool.service';
import { Subject } from 'rxjs';
import { debounceTime } from 'rxjs/operators';

@Component({
  selector: 'app-incident-handle-order',
  templateUrl: './incident-handle-order.component.html',
  styleUrls: ['./incident-handle-order.component.less'],
})
export class IncidentHandleOrderComponent implements OnInit {
  @Input() id: any;

  constructor(
    private mainService: MainService,
    private router: Router,
    private message: NzMessageService,
    private tool: ToolService,
    private fb: FormBuilder,
  ) { }

  hosId:any;
  changeInpSubject = new Subject(); //防抖

  ngOnInit() {
    //防抖
    this.changeInpSubject.pipe(debounceTime(500)).subscribe((v) => {
      if(v[0] === 'consumable'){
        this.getConsumableList(v[1]);
      }
    });
    this.hosId = this.tool.getCurrentHospital().id;
    this.getSummaryList();
    this.getConsumableList();
  }

  // 新增耗材/工时弹框
  modelName = ""; //模态框名称
  modalConsumable: boolean = false; //新增/编辑模态框
  add: boolean; //true:新增；false:编辑
  addConsumable() {
    this.modelName = "新增";
    this.add = true; //新增
    this.modalConsumable = true;
    this.initConsumableForm();
  }
  //关闭新增/编辑弹框
  hideConsumableModal() {
    this.modalConsumable = false;
  }

  // 编辑
  coopData: any = {}; //当前操作列
  editConsumable(data) {
    console.log(data);
    this.modelName = "编辑";
    this.add = false;
    this.modalConsumable = true;
    this.initConsumableForm();
    this.coopData = data;
    this.validateConsumableForm.controls.orders.setValue(data.orders);
    this.validateConsumableForm.controls.workdayClassId.setValue(data.workdayClassId);
  }

  // 新增/编辑表单提交
  btnLoading: boolean = false; //提交按钮loading状态
  submitConsumableForm(): void {
    for (const i in this.validateConsumableForm.controls) {
      this.validateConsumableForm.controls[i].markAsDirty();
      this.validateConsumableForm.controls[i].updateValueAndValidity();
    }
    if (this.validateConsumableForm.invalid) {
      return;
    }
    console.log(this.validateConsumableForm.value);
    this.btnLoading = true;
    let postData:any = {};

    if (this.add) {
      //增加
      postData = {
        "consumableList": [
          {
            "consumablesId": this.validateConsumableForm.value.consumablesId,
            "consumablesNum": this.validateConsumableForm.value.consumablesNum,
          }
        ],
        "summaryId": this.summaryId,
      };
    } else {
      //编辑
      postData = {
        // priority: {
          ...this.coopData,
          ...{
            name: this.validateConsumableForm.value.name,
            orders: this.validateConsumableForm.value.orders,
            responseTime: this.validateConsumableForm.value.responseTime,
            handleTime: this.validateConsumableForm.value.handleTime,
            holidayClassId: this.validateConsumableForm.value.holidayClassId,
            workdayClassId: this.validateConsumableForm.value.workdayClassId,
          }
        // }
      };
    }
    this.mainService
      .addSummaryDoc(postData)
      .subscribe((result) => {
        this.btnLoading = false;
        this.hideConsumableModal();
        let msg = "";
        if (this.add) {
          msg = "新增";
        } else {
          msg = "修改";
        }
        if (result.status == 200) {
          this.showPromptModal(msg, true, '');
        } else {
          this.showPromptModal(msg, false, result.msg);
        }
      });
  }

  // 初始化新增form表单
  validateConsumableForm: FormGroup; //新增/编辑表单
  initConsumableForm() {
    this.validateConsumableForm = this.fb.group({
      consumablesId: [null, [Validators.required]],
      consumablesNum: [1, [Validators.required]],
    });
    console.log(this.validateConsumableForm.controls)
  }

  // 边输边搜节流阀
  isLoading = false;
  changeInp(model, e) {
    this.isLoading = true;
    this.changeInpSubject.next([model, e]);
  }

  // 获取耗材
  consumableList: any = [];
  getConsumableList(keyword = '', isShowValue = false) {
    let postData = {
      consumable: {
        name: keyword,
        hosId: this.hosId,
      },
      idx: 0,
      sum: 20,
    };
    this.mainService
      .getFetchDataList("simple/data", "consumable", postData)
      .subscribe((data) => {
        this.isLoading = false;
        let consumableList = data.list || [];
        if(isShowValue && this.coopData && this.coopData.groupId){
          consumableList = consumableList.filter(v => v.id !== this.coopData.id)
          consumableList.unshift(this.coopData);
        }
        this.consumableList = consumableList;
      });
  }

  // 获取汇总单信息
  summaryObj:any = {
    consumableList: [],//耗材列表
    workHourManagementList: [],//工时列表
  };
  summaryId = undefined;//汇总单Id
  summaryLoading:boolean = false;
  getSummaryList() {
    this.summaryLoading = true;
    let postData = {
      "incidentId": this.id,
    };
    this.mainService
      .querySummaryDocNew(postData)
      .subscribe((res:any) => {
        this.summaryLoading = false;
        if(res.status == 200){
          this.summaryObj = {...{consumableList:[], workHourManagementList: []}, ...res };
          console.log(this.summaryObj)
          this.summaryId = res.summaryId;
        }else if(res.status == 201){
          // 事件第一次绑定汇总单
          this.summaryId = res.summaryId;
        }else{
          this.message.error(res.msg || '请求数据失败！');
        }
      });
  }

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //操作提示框是否展示
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
    this.getSummaryList();
  }
}




