import { Component, OnInit, Input, Output, EventEmitter, ViewChild } from '@angular/core';
import { MainService } from '../../../services/main.service';
import { Router } from '@angular/router';
import { OverlayScrollbarsComponent } from 'overlayscrollbars-ngx';
import { NzMessageService } from 'ng-zorro-antd';
import { ToolService } from 'src/app/services/tool.service';
import { forkJoin } from 'rxjs';

@Component({
  selector: 'app-incident-handle',
  templateUrl: './incident-handle.component.html',
  styleUrls: ['./incident-handle.component.less']
})
export class IncidentHandleComponent implements OnInit {
  @ViewChild("osComponentRef1", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef1: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef2", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef2: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef3", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef3: OverlayScrollbarsComponent;

  @Output() closeModelHs = new EventEmitter<any>();//1.组件暴露一个 EventEmitter 属性，当事件发生时，子组件利用该属性 emits(向上弹射)事件
  @Output() confirmModelHs = new EventEmitter<any>();//1.组件暴露一个 EventEmitter 属性，当事件发生时，子组件利用该属性 emits(向上弹射)事件

  @Input() id: any;

  constructor(
    private mainService: MainService,
    private router: Router,
    private message: NzMessageService,
    private tool: ToolService,
  ) { }

  isLoading = false;
  hosId:any;

  tabs:any[] = [
    { name: '处理信息', value: 1 },
    // { name: '汇总单', value: 2 },
  ]

  // 点击tab
  activeTabValue:any = 1;
  clickTbab(item){
    this.activeTabValue = item.value;
  }

  ngOnInit() {
    this.hosId = this.tool.getCurrentHospital().id;
    this.getDetail();
    this.getHospitalConfig();
  }
  // 关闭弹窗
  hideModal() {
    this.closeModelHs.emit(JSON.stringify({ show: false }));//emits(向上弹射)事件
  }
  // 是否进入汇总单
  get isInSummaryOrder(){
    return this.incidentData.duty && this.itsmSummarySheet.value == 1 && (this.incidentData.handlingPersonnelUser.id == this.tool.getCurrentUserId());
  }

  // 获取院区配置信息
  itsmSummarySheet:any = {};
  getHospitalConfig() {
    let postData = {
      idx: 0,
      sum: 9999,
      hospitalConfig: {
        model: "itsm",
        hosId: this.hosId,
      },
    }
    this.mainService
      .getFetchDataList("simple/data", "hospitalConfig", postData)
      .subscribe((result) => {
        let list = result.list || [];
        this.itsmSummarySheet = list.find(v => v.key == 'itsmSummarySheet') || {};
        if(this.isInSummaryOrder){
          let summary = this.tabs.some(v => v.value == 2);
          !summary && this.tabs.push({ name: '汇总单', value: 2 });
        }
      });
  }

  // 获取详情数据
  incidentData:any = {};
  maskFlag:any = false;
  getDetail() {
    this.maskFlag = this.message.loading("正在加载中..", {
      nzDuration: 0,
    }).messageId;
    this.mainService
      .getFetchData("simple/data", "incident", this.id)
      .subscribe((result) => {
        this.message.remove(this.maskFlag);
        this.maskFlag = false;
        this.incidentData = result.data || {};
        this.incidentData.callID && this.getCallrecord();
        this.incidentData.reqAttachment && this.getRepairImgs();

        this.getDictionaryList();
      });
  }

  // 获取通话音频
  audioSrc =  '';//音频
  getCallrecord() {
    let postData = {
      idx: 0,
      sum: 1,
      callrecord: {callAccept: this.incidentData.callID},
    };
    this.mainService
      .getFetchDataList('simple/data', 'callrecord', postData)
      .subscribe((result) => {
        if(result.status == 200){
          result.list = result.list || [];
          if(result.list.length){
            this.audioSrc = location.origin + result.list[0].recordingFileName;
          }else{
            this.audioSrc = '';
          }
        }else{
          this.message.error(result.msg || '请求数据失败！');
        }
      });
  }

  //获取知识库状态/类型
  knowageLoading:boolean = false;
  getDictionaryList() {
    this.knowageLoading = true;
    let solutionStatus$ = this.mainService.getDictionary('list', 'solution_status', true);
    let solutionType$ = this.mainService.getDictionary('list', 'solution_type', true);
    forkJoin(solutionStatus$, solutionType$).subscribe((data:any[]) => {
      let solutionStatusList = data[0] || [];
      let solutionTypeList = data[1] || [];

      let solutionStatus = solutionStatusList.find(item => item.value == 2);
      	console.log('solutionStatus:', solutionStatus)
      let solutionType = solutionTypeList.find(item => item.value == 1);
      	console.log('solutionType:', solutionType)

      if(solutionStatus && solutionType){
        this.getKnowledgeList(solutionStatus, solutionType);
      }
    })
  }

  // 获取知识库
  knowageList:any[] =  [];
  getKnowledgeList(solutionStatus, solutionType) {
    let postData:any = {
      idx: 0,
      sum: 9999,
      solution: {
        category: this.incidentData.category,
				status: solutionStatus,
				type: solutionType,
      },
    };

    this.mainService
      .getFetchDataList('simple/data', 'solution', postData)
      .subscribe((result) => {
        this.knowageLoading = false;
        if(result.status == 200){
          this.knowageList = result.list || [];
        }else{
          this.message.error(result.msg || '请求数据失败！');
        }
      });
  }

  // 知识库查看-知道了
  coopData:any = {};
  isShowKnowledge:boolean = false;
  showKnowledgeModal(data) {
    this.coopData = data || {};
    this.isShowKnowledge = true;
  }

  cancelKnowledgeModal(flag) {
    this.isShowKnowledge = false;
  }

  // 获取报修图片
  repairImgs:any[] = [];//报修图片
  getRepairImgs() {
    this.mainService
      .getPreviewImage('wechatRequesterIncident', this.id)
      .subscribe((res:any) => {
        res.data = res.data || [];
        res.data.forEach(v => {
          v.previewUrl = location.origin + "/file" + v.relativeFilePath;
          v.thumbFilePath = location.origin + "/file" + v.thumbFilePath;
        })
        this.repairImgs = res.data;
      });
  }

  // 预览图片
  imgs = [];
  isPreview = false;
  initialViewIndex:number = 0;
  previewImageHandler(data = [], index = 0) {
    this.initialViewIndex = index;
    console.log(index)
    this.isPreview = false;
    data = data || [];
    this.imgs = data.map((v) => location.origin + '/file' + v.relativeFilePath);
    setTimeout(() => {
      this.isPreview = true;
    }, 0)
  }

  // 表单提交
  submitForm(): void {
    this.confirmModelHs.emit();
  }
}




