import { NgModule } from "@angular/core";
import { Routes, RouterModule } from "@angular/router";
import { MainComponent } from "./main.component";

const routes: Routes = [
  {
    path: "",
    component: MainComponent,
    children: [
      // 默认跳转到主页
      {
        path: "",
        redirectTo: "home",
        pathMatch: "full",
      },
      // 主页
      {
        path: "home",
        loadChildren: () => import("../home/home.module").then((m) => m.HomeModule),
      },
      // 班次管理
      {
        path: "classesManagement",
        loadChildren: () => import("../classes-management/classes-management.module").then((m) => m.ClassesManagementModule),
      },
      // 节假日管理
      {
        path: "holidaysManagement",
        loadChildren: () => import("../holidays-management/holidays-management.module").then((m) => m.HolidaysManagementModule),
      },
      // 分组管理
      {
        path: "groupManagement",
        loadChildren: () => import("../group-management/group-management.module").then((m) => m.GroupManagementModule),
      },
      // 院区管理
      {
        path: "hospitalManagement",
        loadChildren: () => import("../hospital-management/hospital-management.module").then((m) => m.HospitalManagementModule),
      },
      // 微信配置
      {
        path: "wechatConfig",
        loadChildren: () => import("../wechat-config/wechat-config.module").then((m) => m.WechatConfigModule),
      },
      // 系统配置
      {
        path: "sysConfig",
        loadChildren: () => import("../sys-config/sys-config.module").then((m) => m.SysConfigModule),
      },
      // 数据字典
      {
        path: "dataDictionary",
        loadChildren: () => import("../data-dictionary/data-dictionary.module").then((m) => m.DataDictionaryModule),
      },
      // 科室管理
      {
        path: "officeManagement",
        loadChildren: () => import("../office-management/office-management.module").then((m) => m.OfficeManagementModule),
      },
      // 二维码配置
      {
        path: "QRCodeConfiguration",
        loadChildren: () => import("../qrcode-configuration/qrcode-configuration.module").then((m) => m.QRCodeConfigurationModule),
      },
      // 任务类型管理
      {
        path: "taskTypeManagement",
        loadChildren: () => import("../task-type-management/task-type-management.module").then((m) => m.TaskTypeManagementModule),
      },
      // 手术通知
      {
        path: "operationNotice",
        loadChildren: () => import("../operation-notice/operation-notice.module").then((m) => m.OperationNoticeModule),
      },
      // 血制品页面控制
      {
        path: "bloodProductsConfig",
        loadChildren: () => import("../blood-products-config/blood-products-config.module").then((m) => m.BloodProductsConfigModule),
      },
      // 检查页面控制
      {
        path: "inspectAndPatientTransportConfig",
        loadChildren: () => import("../inspect-and-patient-transport-config/inspect-and-patient-transport-config.module").then((m) => m.InspectAndPatientTransportConfigModule),
      },
      // 手术页面控制
      {
        path: "operationConfig",
        loadChildren: () => import("../operation-config/operation-config.module").then((m) => m.OperationConfigModule),
      },
      // 药品页面控制
      {
        path: "drugPageControl",
        loadChildren: () => import("../drug-page-control/drug-page-control.module").then((m) => m.DrugPageControlModule),
      },
      // 临床服务页面控制
      {
        path: "otherPageControl",
        loadChildren: () => import("../other-page-control/other-page-control.module").then((m) => m.OtherPageControlModule),
      },
      // 被服洗涤-回收页面控制
      {
        path: "quiltWashingGetPageControl",
        loadChildren: () => import("../quilt-washing-get-page-control/quilt-washing-get-page-control.module").then((m) => m.QuiltWashingGetPageControlModule),
      },
      // 被服洗涤-送回页面控制
      {
        path: "quiltWashingSendPageControl",
        loadChildren: () => import("../quilt-washing-send-page-control/quilt-washing-send-page-control.module").then((m) => m.QuiltWashingSendPageControlModule),
      },
      // 医废页面控制
      {
        path: "medicalWastePageControl",
        loadChildren: () => import("../medical-waste-page-control/medical-waste-page-control.module").then((m) => m.MedicalWastePageControlModule),
      },
      // 限制发起时间
      {
        path: "limitInitiationTime",
        loadChildren: () => import("../limit-initiation-time/limit-initiation-time.module").then((m) => m.LimitInitiationTimeModule),
      },
      // 关联数据
      {
        path: "associatedData",
        loadChildren: () => import("../associated-data/associated-data.module").then((m) => m.AssociatedDataModule),
      },
      // 工作分配方案列表
      {
        path: "workAssignment",
        loadChildren: () => import("../work-assignment/work-assignment.module").then((m) => m.WorkAssignmentModule),
      },
      // 老工作分配方案
      {
        path: "jobAssignment",
        loadChildren: () => import("../job-assignment/job-assignment.module").then((m) => m.JobAssignmentModule),
      },
      // 工作分配方案快速组合
      {
        path: "quickCombination",
        loadChildren: () => import("../quick-combination/quick-combination.module").then((m) => m.QuickCombinationModule),
      },
      // 用户管理
      {
        path: "usersManagement",
        loadChildren: () => import("../users-management/users-management.module").then((m) => m.UsersManagementModule),
      },
      // 临床用户
      {
        path: "clinicalUsersManagement",
        loadChildren: () => import("../clinical-users-management/clinical-users-management.module").then((m) => m.ClinicalUsersManagementModule),
      },
      // TAB自定义
      {
        path: "tabCustom",
        loadChildren: () => import("../tab-custom/tab-custom.module").then((m) => m.TabCustomModule),
      },
      // 权限管理
      {
        path: "jurisdictionManagement",
        loadChildren: () => import("../jurisdiction-management/jurisdiction-management.module").then((m) => m.JurisdictionManagementModule),
      },
      // 意见箱
      {
        path: "adviceManagement",
        loadChildren: () => import("../advice-management/advice-management.module").then((m) => m.AdviceManagementModule),
      },
      // 差评处理
      {
        path: "appraiseManagement",
        loadChildren: () => import("../appraise-management/appraise-management.module").then((m) => m.AppraiseManagementModule),
      },
      // 工单列表
      {
        path: "orderManagement",
        loadChildren: () => import("../order-management/order-management.module").then((m) => m.OrderManagementModule),
      },
      // 核酸接收列表
      {
        path: "nucleicAcidCollection",
        loadChildren: () => import("../nucleic-acid-collection/nucleic-acid-collection.module").then((m) => m.NucleicAcidCollectionModule),
      },
      // 表单管理列表
      {
        path: "formManagement",
        loadChildren: () => import("../form-management/form-management.module").then((m) => m.FormManagementModule),
      },
      // 表单管理列表详情
      {
        path: "formManagementDetail/:id/:taskType",
        loadChildren: () => import("../form-management-detail/form-management-detail.module").then((m) => m.FormManagementDetailModule),
      },
      // 工单日志列表
      {
        path: "workOrderLog",
        loadChildren: () => import("../work-order-log/work-order-log.module").then((m) => m.WorkOrderLogModule),
      },
      // 洗涤批次管理
      {
        path: "washingBatch",
        loadChildren: () => import("../washing-batch/washing-batch.module").then((m) => m.WashingBatchModule),
      },
      // 统计分析-综合统计
      {
        path: "compreStatistics",
        loadChildren: () => import("../compre-statistics/compre-statistics.module").then((m) => m.CompreStatisticsModule),
      },
      // 统计分析-任务类型统计
      {
        path: "taskTypeStatistics",
        loadChildren: () => import("../task-type-statistics/task-type-statistics.module").then((m) => m.TaskTypeStatisticsModule),
      },
      // 统计分析-科室统计
      {
        path: "deptStatistics",
        loadChildren: () => import("../dept-statistics/dept-statistics.module").then((m) => m.DeptStatisticsModule),
      },
      // 统计分析-工单统计
      {
        path: "orderStatistics",
        loadChildren: () => import("../order-statistics/order-statistics.module").then((m) => m.OrderStatisticsModule),
      },
      // 统计分析-配送人员统计
      {
        path: "workerStatistics",
        loadChildren: () => import("../worker-statistics/worker-statistics.module").then((m) => m.WorkerStatisticsModule),
      },
      // 统计分析-科室检查率统计
      {
        path: "deptInspectionRateStatistics",
        loadChildren: () => import("../dept-inspection-rate-statistics/dept-inspection-rate-statistics.module").then((m) => m.DeptInspectionRateStatisticsModule),
      },
      // 统计分析-楼栋检查率统计
      {
        path: "buildingInspectionRateStatistics",
        loadChildren: () => import("../building-inspection-rate-statistics/building-inspection-rate-statistics.module").then((m) => m.BuildingInspectionRateStatisticsModule),
      },
      // 统计分析-科室检查统计
      {
        path: "deptInspectionStatistics",
        loadChildren: () => import("../dept-inspection-statistics/dept-inspection-statistics.module").then((m) => m.DeptInspectionStatisticsModule),
      },
      // 统计分析-楼栋检查统计
      {
        path: "buildingInspectionStatistics",
        loadChildren: () => import("../building-inspection-statistics/building-inspection-statistics.module").then((m) => m.BuildingInspectionStatisticsModule),
      },
      // 轮巡计划列表
      {
        path: "roundRobin",
        loadChildren: () => import("../round-robin/round-robin.module").then((m) => m.RoundRobinModule),
      },
      // 快捷建单列表
      {
        path: "shortcutBuildOrders",
        loadChildren: () => import("../shortcut-build-orders/shortcut-build-orders.module").then((m) => m.ShortcutBuildOrdersModule),
      },
      // 快捷接单
      {
        path: "quickOrderAcceptance",
        loadChildren: () => import("../quick-order-acceptance/quick-order-acceptance.module").then((m) => m.QuickOrderAcceptanceModule),
      },
      // 通话记录列表
      {
        path: "callLog",
        loadChildren: () => import("../call-log/call-log.module").then((m) => m.CallLogModule),
      },
      // 定时消息发送列表
      {
        path: "timingMessageSending",
        loadChildren: () => import("../timing-message-sending/timing-message-sending.module").then((m) => m.TimingMessageSendingModule),
      },
      // 定时下班
      {
        path: "regularOffDuty",
        loadChildren: () => import("../regular-off-duty/regular-off-duty.module").then((m) => m.RegularOffDutyModule),
      },
      // 标本信息
      {
        path: "specimenSearch",
        loadChildren: () => import("../specimen-search/specimen-search.module").then((m) => m.SpecimenSearchModule),
      },
      // 检查信息
      {
        path: "inspectSearch",
        loadChildren: () => import("../inspect-search/inspect-search.module").then((m) => m.InspectSearchModule),
      },
      // 患者信息
      {
        path: "patientSearch",
        loadChildren: () => import("../patient-search/patient-search.module").then((m) => m.PatientSearchModule),
      },
      // 药品信息
      {
        path: "drugSearch",
        loadChildren: () => import("../drug-search/drug-search.module").then((m) => m.DrugSearchModule),
      },
      // 静配信息
      {
        path: "jpSearch",
        loadChildren: () => import("../jp-search/jp-search.module").then((m) => m.JpSearchModule),
      },
      // 血制品信息
      {
        path: "bloodSearch",
        loadChildren: () => import("../blood-search/blood-search.module").then((m) => m.BloodSearchModule),
      },
      // 数据核对
      {
        path: "infoSearch",
        loadChildren: () => import("../info-search/info-search.module").then((m) => m.InfoSearchModule),
      },
      // 被服洗涤
      {
        path: "quiltWashingSearch",
        loadChildren: () => import("../quilt-washing-search/quilt-washing-search.module").then((m) => m.QuiltWashingSearchModule),
      },
      // 院区系统配置
      {
        path: "hospitalConfig",
        loadChildren: () => import("../hospital-config/hospital-config.module").then((m) => m.HospitalConfigModule),
      },
      // 楼栋绩效
      {
        path: "buildingDistance",
        loadChildren: () => import("../building-distance/building-distance.module").then((m) => m.BuildingDistanceModule),
      },
      // 陪检绩效
      {
        path: "inspectionDistance",
        loadChildren: () => import("../inspection-distance/inspection-distance.module").then((m) => m.InspectionDistanceModule),
      },
      // 科室绩效
      {
        path: "departmentDistance",
        loadChildren: () => import("../department-distance/department-distance.module").then((m) => m.DepartmentDistanceModule),
      },
      // 检查类型配置
      {
        path: "inspectTypeConfig",
        loadChildren: () => import("../inspect-type-config/inspect-type-config.module").then((m) => m.InspectTypeConfigModule),
      },
      // 检查科室异常设置
      {
        path: "checkDeptException",
        loadChildren: () => import("../check-dept-exception/check-dept-exception.module").then((m) => m.CheckDeptExceptionModule),
      },
      // 检查排除
      {
        path: "checkAndExcludeConfig",
        loadChildren: () => import("../check-and-exclude-config/check-and-exclude-config.module").then((m) => m.CheckAndExcludeConfigModule),
      },
      // 工单消息设置
      {
        path: "workorderMessage",
        loadChildren: () => import("../workorder-message/workorder-message.module").then((m) => m.WorkorderMessageModule),
      },
      // 楼栋楼层
      {
        path: "buildingFloor",
        loadChildren: () => import("../building-floor/building-floor.module").then((m) => m.BuildingFloorModule),
      },
      // 被服科室绑定
      {
        path: "quiltDepartmentBind",
        loadChildren: () => import("../quilt-department-bind/quilt-department-bind.module").then((m) => m.QuiltDepartmentBindModule),
      },
      // 序号设置
      {
        path: "serialNumberSetting",
        loadChildren: () => import("../serial-number-setting/serial-number-setting.module").then((m) => m.SerialNumberSettingModule),
      },
      // 检查自动建单
      {
        path: "inspectAuto",
        loadChildren: () => import("../inspect-auto/inspect-auto.module").then((m) => m.InspectAutoModule),
      },
      // 临床其他建单
      {
        path: "otherAuto",
        loadChildren: () => import("../other-auto/other-auto.module").then((m) => m.OtherAutoModule),
      },
      // 人员检查主动服务统计
      {
        path: "inspectActive",
        loadChildren: () => import("../inspect-active/inspect-active.module").then((m) => m.InspectActiveModule),
      },
      // 建单来源统计
      {
        path: "orderSourceStatistics",
        loadChildren: () => import("../order-source-statistics/order-source-statistics.module").then((m) => m.OrderSourceStatisticsModule),
      },
      // 科室建单来源统计
      {
        path: "deptOrderSourceStatistics",
        loadChildren: () => import("../dept-order-source-statistics/dept-order-source-statistics.module").then((m) => m.DeptOrderSourceStatisticsModule),
      },
      // 任务类型建单来源统计
      {
        path: "tasktypeOrderSourceStatistics",
        loadChildren: () => import("../tasktype-order-source-statistics/tasktype-order-source-statistics.module").then((m) => m.TasktypeOrderSourceStatisticsModule),
      },
      // 问卷调查管理列表
      {
        path: "questionnaireManagement",
        loadChildren: () => import("../questionnaire-management/questionnaire-management.module").then((m) => m.QuestionnaireManagementModule),
      },
      // 问卷问题列表
      {
        path: "questions",
        loadChildren: () => import("../questions/questions.module").then((m) => m.QuestionsModule),
      },
      // 问卷回收数据列表
      {
        path: "questionnaireAnswer",
        loadChildren: () => import("../questionnaire-answer/questionnaire-answer.module").then((m) => m.QuestionnaireAnswerModule),
      },
			// 陪检问卷配置
			{
			  path: "accExamineSet",
			  loadChildren: () => import("../acc-examine-set/acc-examine-set.module").then((m) => m.AccExamineSetModule),
			},
      // 条码预制
      {
        path: "barcodePrefabrication",
        loadChildren: () => import("../barcode-prefabrication/barcode-prefabrication.module").then((m) => m.BarcodePrefabricationModule),
      },
      // 单位管理
      {
        path: "unitManagement",
        loadChildren: () => import("../unit-management/unit-management.module").then((m) => m.UnitManagementModule),
      },
      // 医废类型
      {
        path: "medicalWasteType",
        loadChildren: () => import("../medical-waste-type/medical-waste-type.module").then((m) => m.MedicalWasteTypeModule),
      },
      // 回收限制管理
      {
        path: "recyclingRestriction",
        loadChildren: () => import("../recycling-restriction/recycling-restriction.module").then((m) => m.RecyclingRestrictionModule),
      },
      // 库存信息
      {
        path: "inventoryInformation",
        loadChildren: () => import("../inventory-information/inventory-information.module").then((m) => m.InventoryInformationModule),
      },
      // 医废信息
      {
        path: "medicalWasteInformation",
        loadChildren: () => import("../medical-waste-information/medical-waste-information.module").then((m) => m.MedicalWasteInformationModule),
      },
      // 入库记录
      {
        path: "storageRecord",
        loadChildren: () => import("../medical-waste-storage-record/medical-waste-storage-record.module").then((m) => m.MedicalWasteStorageRecordModule),
      },
      // 出库记录
      {
        path: "outgoingRecord",
        loadChildren: () => import("../medical-waste-outgoing-record/medical-waste-outgoing-record.module").then((m) => m.MedicalWasteOutgoingRecordModule),
      },
      // 批量出库
      {
        path: "batchOutOfStorage",
        loadChildren: () => import("../medical-waste-batch-out-of-storage/medical-waste-batch-out-of-storage.module").then((m) => m.MedicalWasteBatchOutOfStorageModule),
      },
      // 绩效基础配置
      {
        path: "performanceAllocation",
        loadChildren: () => import("../performance-allocation/performance-allocation.module").then((m) => m.PerformanceAllocationModule),
      },
      // 被服统计-人员统计
      {
        path: "quiltWashingPersonnelStatistics",
        loadChildren: () => import("../quilt-washing-personnel-statistics/quilt-washing-personnel-statistics.module").then((m) => m.QuiltWashingPersonnelStatisticsModule),
      },
      // 被服统计-科室统计
      {
        path: "quiltWashingDepartmentStatistics",
        loadChildren: () => import("../quilt-washing-department-statistics/quilt-washing-department-statistics.module").then((m) => m.QuiltWashingDepartmentStatisticsModule),
      },
      // 被服统计-全院统计
      {
        path: "quiltWashingHospitalStatistics",
        loadChildren: () => import("../quilt-washing-hospital-statistics/quilt-washing-hospital-statistics.module").then((m) => m.QuiltWashingHospitalStatisticsModule),
      },
      // 被服统计-趋势分析
      {
        path: "quiltWashingTrendAnalysis",
        loadChildren: () => import("../quilt-washing-trend-analysis/quilt-washing-trend-analysis.module").then((m) => m.QuiltWashingTrendAnalysisModule),
      },
      // 医废统计-人员统计
      {
        path: "medicalWastePersonnelStatistics",
        loadChildren: () => import("../medical-waste-personnel-statistics/medical-waste-personnel-statistics.module").then((m) => m.MedicalWastePersonnelStatisticsModule),
      },
      // 医废统计-科室统计
      {
        path: "medicalWasteDepartmentStatistics",
        loadChildren: () => import("../medical-waste-department-statistics/medical-waste-department-statistics.module").then((m) => m.MedicalWasteDepartmentStatisticsModule),
      },
      // 医废统计-全院统计
      {
        path: "medicalWasteHospitalStatistics",
        loadChildren: () => import("../medical-waste-hospital-statistics/medical-waste-hospital-statistics.module").then((m) => m.MedicalWasteHospitalStatisticsModule),
      },
      // 医废统计-趋势分析
      {
        path: "medicalWasteTrendAnalysis",
        loadChildren: () => import("../medical-waste-trend-analysis/medical-waste-trend-analysis.module").then((m) => m.MedicalWasteTrendAnalysisModule),
      },
			// 大输液配置
			{
			  path: "bigTransfusionSet",
			  loadChildren: () => import("../big-transfusion-set/big-transfusion-set.module").then((m) => m.BigTransfusionSetModule),
			},
			// 药品信息
			{
			  path: "drugInfo",
			  loadChildren: () => import("../drug-info/drug-info.module").then((m) => m.DrugInfoModule),
			},
			// 科室发药单
			{
			  path: "adminOfficePrescription",
			  loadChildren: () => import("../admin-office-prescription/admin-office-prescription.module").then((m) => m.AdminOfficePrescriptionModule),
			},
			// 药品云库存
			{
			  path: "drugCloud",
			  loadChildren: () => import("../drug-cloud/drug-cloud.module").then((m) => m.DrugCloudModule),
			},
			// 发药批次
			{
			  path: "dispensingBatch",
			  loadChildren: () => import("../dispensing-batch/dispensing-batch.module").then((m) => m.DispensingBatchModule),
			},
      // 巡检单配置
      {
        path: "inspectionConfiguration",
        loadChildren: () => import("../inspection-configuration/inspection-configuration.module").then((m) => m.InspectionConfigurationModule),
      },
      // 巡检项配置
      {
        path: "inspectionConfigurationItem",
        loadChildren: () => import("../inspection-configuration-item/inspection-configuration-item.module").then((m) => m.InspectionConfigurationItemModule),
      },
      // 巡检点
      {
        path: "inspectionAddress",
        loadChildren: () => import("../inspection-address/inspection-address.module").then((m) => m.InspectionAddressModule),
      },
      // 巡检计划
      {
        path: "inspectionPlan",
        loadChildren: () => import("../inspection-plan/inspection-plan.module").then((m) => m.InspectionPlanModule),
      },
      // 巡检批次
      {
        path: "inspectionBatch",
        loadChildren: () => import("../inspection-batch/inspection-batch.module").then((m) => m.InspectionBatchModule),
      },
      // 巡检执行
      {
        path: "inspectionExecute",
        loadChildren: () => import("../inspection-execute/inspection-execute.module").then((m) => m.InspectionExecuteModule),
      },
			// 故障管理-知识库管理
			{
			  path: "repositoryManage",
			  loadChildren: () => import("../repository-manage/repository-manage.module").then((m) => m.RepositoryManageModule),
			},
      // 三方公司
      {
        path: "tripartiteCompany",
        loadChildren: () => import("../tripartite-company/tripartite-company.module").then((m) => m.TripartiteCompanyModule),
      },
      // 资产信息
      {
        path: "assetsInfo",
        loadChildren: () => import("../assets-info/assets-info.module").then((m) => m.AssetsInfoModule),
      },
      // 产品管理
      {
        path: "assetsProductManagement",
        loadChildren: () => import("../assets-product-management/assets-product-management.module").then((m) => m.AssetsProductManagementModule),
      },
      // 耗材库
      {
        path: "assetsConsumable",
        loadChildren: () => import("../assets-consumable/assets-consumable.module").then((m) => m.AssetsConsumableModule),
      },
      // 工单列表
      {
        path: "incidentManagement",
        loadChildren: () => import("../incident-management/incident-management.module").then((m) => m.IncidentManagementModule),
      },
    ],
  },
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule],
})
export class MainRoutingModule {}
